summaryrefslogtreecommitdiff
path: root/epan/tap.h
diff options
context:
space:
mode:
authorPascal Quantin <pascal.quantin@gmail.com>2016-06-19 11:01:56 +0200
committerPascal Quantin <pascal.quantin@gmail.com>2016-06-19 10:47:10 +0000
commita383e692c8774c2451a55d8b3f8ef9db5d037329 (patch)
treeab6223527915ab1127a50563981816adc18b971f /epan/tap.h
parentff845123f1f1ecef0d8e0d8980e6e9d7267e5f6b (diff)
downloadwireshark-a383e692c8774c2451a55d8b3f8ef9db5d037329.tar.gz
Revert "tap: change glib functions to wmem."
This reverts commit 2e9f3c5d366eaa7139fc877b5301392166b3f985. It breaks the registration of codec, dissector and libwiretap plugins. Change-Id: I4ef91dd192f765adf87ea9fe9f3693e25dbd24de Reviewed-on: https://code.wireshark.org/review/16012 Petri-Dish: Pascal Quantin <pascal.quantin@gmail.com> Reviewed-by: Pascal Quantin <pascal.quantin@gmail.com>
Diffstat (limited to 'epan/tap.h')
-rw-r--r--epan/tap.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/epan/tap.h b/epan/tap.h
index c17bafcd5e..c3b427f008 100644
--- a/epan/tap.h
+++ b/epan/tap.h
@@ -140,8 +140,8 @@ WS_DLL_PUBLIC void draw_tap_listeners(gboolean draw_all);
/** this function attaches the tap_listener to the named tap.
* function returns :
* NULL: ok.
* non-NULL: error, return value points to gchar* containing error
* message. This value must be freed with wmem_free().
* @param tapname The name of the tap we want to listen to.
* @param tapdata is the instance identifier. The tap system uses the value of this
* pointer to distinguish between different instances of a tap.
@@ -211,12 +211,12 @@ WS_DLL_PUBLIC void draw_tap_listeners(gboolean draw_all);
* or the file has been [re]read completely.
*/
-WS_DLL_PUBLIC gchar *register_tap_listener(const char *tapname, void *tapdata,
+WS_DLL_PUBLIC GString *register_tap_listener(const char *tapname, void *tapdata,
const char *fstring, guint flags, tap_reset_cb tap_reset,
tap_packet_cb tap_packet, tap_draw_cb tap_draw);
/** This function sets a new dfilter to a tap listener */
-WS_DLL_PUBLIC gchar *set_tap_dfilter(void *tapdata, const char *fstring);
+WS_DLL_PUBLIC GString *set_tap_dfilter(void *tapdata, const char *fstring);
/** This function recompiles dfilter for all registered tap listeners */
WS_DLL_PUBLIC void tap_listeners_dfilter_recompile(void);
@@ -140,8 +140,8 @@ WS_DLL_PUBLIC void draw_tap_listeners(gboolean draw_all);
* function returns :
* NULL: ok.
- * non-NULL: error, return value points to gchar* containing error
- * message. This value must be freed with wmem_free().
+ * non-NULL: error, return value points to GString containing error
+ * message.
* @param tapname The name of the tap we want to listen to.
* @param tapdata is the instance identifier. The tap system uses the value of this